@@ -27,7 +27,12 @@ if (freeEdges["top"] == true) {
 
 panel.height = gridUnit * 1.7
 
+var spacer1 = panel.addWidget("org.kde.plasma.panelspacer")
+spacer1.writeConfig("expanding", "false")
+spacer1.writeConfig("length", "10")
+
 var kicker = panel.addWidget("org.kde.plasma.kicker")
+kicker.writeConfig("customButtonImage", "/usr/share/pixmaps/ubuntustudio-logo-menu.png")
 kicker.writeConfig("favoriteApps", "preferred://browser,org.kde.discover.desktop,systemsettings.desktop,org.kde.dolphin.desktop,org.kde.kate.desktop,patchance.desktop,ardour.desktop,com.obsproject.Studio.desktop,org.kde.krita.desktop,gimp.desktop,org.kde.kdenlive.desktop,org.kde.digikam.desktop,org.darktable.darktable.desktop")
 kicker.writeConfig("showAppsByName", "true")
 kicker.currentConfigGroup = ["Shortcuts"]
@@ -39,14 +44,6 @@ panel.addWidget("org.kde.plasma.pager")
 
 var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
 var launcherlist = [ "preferred://browser",
-                     "applications:patchance.desktop",
-                     "applications:ardour.desktop",
-                     "applications:com.obsproject.Studio.desktop",
-                     "applications:org.kde.krita.desktop",
-                     "applications:gimp.desktop",
-                     "applications:org.kde.kdenlive.desktop",
-                     "applications:org.kde.digikam.desktop",
-                     "applications:org.darktable.darktable.desktop",
                      "applications:systemsettings.desktop" ]
 taskmanager.writeConfig("launchers", launcherlist)
 
@@ -96,3 +93,7 @@ if (langIds.indexOf(languageId) != -1) {
 panel.addWidget("org.kde.plasma.systemtray")
 panel.addWidget("org.kde.plasma.digitalclock")
 panel.addWidget("org.kde.plasma.minimizeall")
+
+var spacer2 = panel.addWidget("org.kde.plasma.panelspacer")
+spacer2.writeConfig("expanding", "false")
+spacer2.writeConfig("length", "10")
